.. image:: https://github.com/multiscale/muscle3/raw/develop/docs/source/muscle3_logo_readme.png
    :alt: MUSCLE3

.. image:: https://readthedocs.org/projects/muscle3/badge/?version=master
    :target: https://muscle3.readthedocs.io/en/develop/?badge=master
    :alt: Documentation Build Status

.. image:: https://github.com/multiscale/muscle3/actions/workflows/ci.yaml/badge.svg?branch=master
    :target: https://github.com/multiscale/muscle3/actions
    :alt: Build Status

.. image:: https://zenodo.org/badge/122876985.svg
   :target: https://zenodo.org/badge/latestdoi/122876985

.. image:: https://img.shields.io/badge/rsd-muscle3-00a3e3.svg
   :target: https://www.research-software.nl/software/muscle3

|

MUSCLE3 is the third incarnation of the MUSCLE Multiscale Coupling Library and
Environment. With MUSCLE3, you can connect multiple simulation models together into
a multiscale simulation.

Browse to `the MUSCLE3 documentation`_ to get started.


Collaboration
=============

For academic collaboration, please contact `prof. Alfons Hoekstra (UvA CSL) <https://www.uva.nl/profiel/h/o/a.g.hoekstra/a.g.hoekstra.html>`_
and/or `Lourens Veen (NLeSC) <https://www.esciencecenter.nl/team/lourens-veen-msc/>`_.

Commercial support for MUSCLE3 is provided by
`Ignition Computing <https://www.ignitioncomputing.com>`_.


Legal
=====

MUSCLE3 is Copyright 2018-2022 University of Amsterdam and Netherlands eScience
Center, Copyright 2022-2024 The ITER Organisation, and Copyright 2023-2025 Netherlands
eScience Center. It is licensed under the Apache License 2.0.


Contributing
============

We welcome contributions to MUSCLE3! For small additions or fixes, please
submit a pull request, and we'll review your changes and apply them. If you
want to add larger features, please make an issue and describe what you want to
do, so that we can coordinate and avoid double work. For more details, see the
`documentation on contributing`_.

The MUSCLE3 community fosters a welcoming atmosphere, and participation is open
to everyone. In order to ensure that it stays that way, we have a
`code of conduct`_, and we will enforce it if necessary. Please treat your
fellow human beings with respect.


.. _`the MUSCLE3 documentation`: https://muscle3.readthedocs.io
.. _`documentation on contributing`: http://muscle3.readthedocs.io/en/latest/contributing.html
.. _`code of conduct`: https://github.com/multiscale/muscle3/blob/develop/CODE_OF_CONDUCT.rst
